# DiscoverSnoop.AlertsApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**alertsChangeGet**](AlertsApi.md#alertsChangeGet) | **GET** /alerts_change | Edit or insert new alert
[**alertsDeleteGet**](AlertsApi.md#alertsDeleteGet) | **GET** /alerts_delete | Permanently delete the alert
[**alertsGet**](AlertsApi.md#alertsGet) | **GET** /alerts | Get alerts for user account

<a name="alertsChangeGet"></a>
# **alertsChangeGet**
> [Domains] alertsChangeGet(id, alertname, activated, type, channel, recipient, opts)

Edit or insert new alert

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.AlertsApi();
let id = "id_example"; // String | ID of the alert to edit ; if adding a new one leave blank
let alertname = "alertname_example"; // String | Name of the alert
let activated = true; // Boolean | Should the alert be activated or not
let type = 56; // Number | Alert type (1= New content for website, 2=New performing contents), 3=New contents in category
let channel = 56; // Number | 1 for email, 2 for Slack, 3 for Google Chat, 4 for JSON
let recipient = "recipient_example"; // String | Email address of recipient or webhook for Slack/Gchat or JSON endpoint
let opts = { 
  'param1': "param1_example", // String | Parameter 1 (meaning changes with alert type)
  'param2': "param2_example", // String | Parameter 2 (meaning changes with alert type)
  'param3': "param3_example", // String | Parameter 3 (meaning changes with alert type)
  'param4': "param4_example", // String | Parameter 4 (meaning changes with alert type)
  'param5': "param5_example", // String | Parameter 5 (meaning changes with alert type)
  'param6': "param6_example" // String | Parameter 6 (meaning changes with alert type)
};
apiInstance.alertsChangeGet(id, alertname, activated, type, channel, recipient, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the alert to edit ; if adding a new one leave blank | 
 **alertname** | **String**| Name of the alert | 
 **activated** | **Boolean**| Should the alert be activated or not | 
 **type** | **Number**| Alert type (1&#x3D; New content for website, 2&#x3D;New performing contents), 3&#x3D;New contents in category | 
 **channel** | **Number**| 1 for email, 2 for Slack, 3 for Google Chat, 4 for JSON | 
 **recipient** | **String**| Email address of recipient or webhook for Slack/Gchat or JSON endpoint | 
 **param1** | **String**| Parameter 1 (meaning changes with alert type) | [optional] 
 **param2** | **String**| Parameter 2 (meaning changes with alert type) | [optional] 
 **param3** | **String**| Parameter 3 (meaning changes with alert type) | [optional] 
 **param4** | **String**| Parameter 4 (meaning changes with alert type) | [optional] 
 **param5** | **String**| Parameter 5 (meaning changes with alert type) | [optional] 
 **param6** | **String**| Parameter 6 (meaning changes with alert type) | [optional] 

### Return type

[**[Domains]**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="alertsDeleteGet"></a>
# **alertsDeleteGet**
> [TransactionInfo] alertsDeleteGet(id)

Permanently delete the alert

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.AlertsApi();
let id = "id_example"; // String | alert id to delete

apiInstance.alertsDeleteGet(id, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| alert id to delete | 

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="alertsGet"></a>
# **alertsGet**
> [Alerts] alertsGet()

Get alerts for user account

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.AlertsApi();
apiInstance.alertsGet((error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**[Alerts]**](Alerts.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

