# DiscoverSnoop.FavsApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**favsAddGet**](FavsApi.md#favsAddGet) | **GET** /favs_add | Create a new fav
[**favsDeleteGet**](FavsApi.md#favsDeleteGet) | **GET** /favs_delete | Permanently delete the fav
[**favsGet**](FavsApi.md#favsGet) | **GET** /favs | Get favorites
[**favsUpdateGet**](FavsApi.md#favsUpdateGet) | **GET** /favs_update | Update the fav

<a name="favsAddGet"></a>
# **favsAddGet**
> [TransactionInfo] favsAddGet(opts)

Create a new fav

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.FavsApi();
let opts = { 
  'name': "name_example", // String | Name of the fav.
  'action': "action_example", // String | Action to be opened.
  'parameters': "parameters_example" // String | Action's parameters encoded in JSON.
};
apiInstance.favsAddGet(opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| Name of the fav. | [optional] 
 **action** | **String**| Action to be opened. | [optional] 
 **parameters** | **String**| Action&#x27;s parameters encoded in JSON. | [optional] 

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="favsDeleteGet"></a>
# **favsDeleteGet**
> [TransactionInfo] favsDeleteGet(opts)

Permanently delete the fav

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.FavsApi();
let opts = { 
  'id': "id_example" // String | ID of the fav to delete.
};
apiInstance.favsDeleteGet(opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the fav to delete. | [optional] 

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="favsGet"></a>
# **favsGet**
> [Favs] favsGet(opts)

Get favorites

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.FavsApi();
let opts = { 
  'id': "id_example" // String | ID of the requested fav. ignore or set to 0 to get the full favs list
};
apiInstance.favsGet(opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the requested fav. ignore or set to 0 to get the full favs list | [optional] 

### Return type

[**[Favs]**](Favs.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="favsUpdateGet"></a>
# **favsUpdateGet**
> [TransactionInfo] favsUpdateGet(id, opts)

Update the fav

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.FavsApi();
let id = "id_example"; // String | ID of the fav that should be edited
let opts = { 
  'name': "name_example", // String | Name of the fav.
  'action': "action_example", // String | Action to be opened.
  'parameters': "parameters_example", // String | Action's parameters encoded in JSON.
  'scheduled': 56, // Number | 0 if not scheduled, else x in hours
  'scheduledto': "scheduledto_example" // String | email address of the recipient of this report
};
apiInstance.favsUpdateGet(id, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| ID of the fav that should be edited | 
 **name** | **String**| Name of the fav. | [optional] 
 **action** | **String**| Action to be opened. | [optional] 
 **parameters** | **String**| Action&#x27;s parameters encoded in JSON. | [optional] 
 **scheduled** | **Number**| 0 if not scheduled, else x in hours | [optional] 
 **scheduledto** | **String**| email address of the recipient of this report | [optional] 

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

