# DiscoverSnoop.HistoricalApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**categoriesGet**](HistoricalApi.md#categoriesGet) | **GET** /categories | Get historical stats for categories
[**categoryGet**](HistoricalApi.md#categoryGet) | **GET** /category | Get history for category ID
[**domainGet**](HistoricalApi.md#domainGet) | **GET** /domain | Get history for domain name
[**domainsGet**](HistoricalApi.md#domainsGet) | **GET** /domains | Get historical stats for domains
[**entitiesGet**](HistoricalApi.md#entitiesGet) | **GET** /entities | Get historical stats for entities
[**entityGet**](HistoricalApi.md#entityGet) | **GET** /entity | Get history for entity
[**pageGet**](HistoricalApi.md#pageGet) | **GET** /page | Get page history for URL
[**pagesGet**](HistoricalApi.md#pagesGet) | **GET** /pages | Get historical stats for pages

<a name="categoriesGet"></a>
# **categoriesGet**
> [Categories] categoriesGet(country, opts)

Get historical stats for categories

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.HistoricalApi();
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'fromDate': "fromDate_example", // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'toDate': "toDate_example", // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'keywordFilter': "keywordFilter_example", // String | Filter answers to cateogry names containing a particular keyword
  'lines': 50, // Number | Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more)
  'offset': 0 // Number | Get paginated results from X offset
};
apiInstance.categoriesGet(country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **keywordFilter** | **String**| Filter answers to cateogry names containing a particular keyword | [optional] 
 **lines** | **Number**| Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Number**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**[Categories]**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="categoryGet"></a>
# **categoryGet**
> [Category] categoryGet(id, country, opts)

Get history for category ID

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.HistoricalApi();
let id = "id_example"; // String | category id
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'fromDate': "fromDate_example", // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'toDate': "toDate_example" // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
};
apiInstance.categoryGet(id, country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| category id | 
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**[Category]**](Category.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="domainGet"></a>
# **domainGet**
> [Domain] domainGet(domain, country, opts)

Get history for domain name

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.HistoricalApi();
let domain = "domain_example"; // String | domain name (no subdomain allowed)
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'fromDate': "fromDate_example", // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'toDate': "toDate_example" // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
};
apiInstance.domainGet(domain, country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **domain** | **String**| domain name (no subdomain allowed) | 
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**[Domain]**](Domain.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="domainsGet"></a>
# **domainsGet**
> [Domains] domainsGet(country, opts)

Get historical stats for domains

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.HistoricalApi();
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'fromDate': "fromDate_example", // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'toDate': "toDate_example", // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'urlFilter': "urlFilter_example", // String | Filter answers to domains including a specified string
  'lines': 50, // Number | Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more)
  'offset': 0 // Number | Get paginated results from X offset
};
apiInstance.domainsGet(country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **urlFilter** | **String**| Filter answers to domains including a specified string | [optional] 
 **lines** | **Number**| Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Number**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**[Domains]**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="entitiesGet"></a>
# **entitiesGet**
> [Entities] entitiesGet(country, opts)

Get historical stats for entities

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.HistoricalApi();
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'fromDate': "fromDate_example", // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'toDate': "toDate_example", // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'keywordFilter': "keywordFilter_example", // String | Filter answers to entity names containing a particular keyword
  'lines': 50, // Number | Get X results (max in one request is 50000 a request with more than 50000 will be downgraded to 10000 please use offset paginated results if you need more)
  'offset': 0 // Number | Get paginated results from X offset
};
apiInstance.entitiesGet(country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **keywordFilter** | **String**| Filter answers to entity names containing a particular keyword | [optional] 
 **lines** | **Number**| Get X results (max in one request is 50000 a request with more than 50000 will be downgraded to 10000 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Number**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**[Entities]**](Entities.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="entityGet"></a>
# **entityGet**
> [Entity] entityGet(name, country, opts)

Get history for entity

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.HistoricalApi();
let name = "name_example"; // String | entity exact name URL encoded
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'fromDate': "fromDate_example", // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'toDate': "toDate_example" // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
};
apiInstance.entityGet(name, country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| entity exact name URL encoded | 
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**[Entity]**](Entity.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pageGet"></a>
# **pageGet**
> [Page] pageGet(url, country, opts)

Get page history for URL

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.HistoricalApi();
let url = "url_example"; // String | Fully qualified page url. URL needs to be URL encoded
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'fromDate': "fromDate_example", // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  'toDate': "toDate_example" // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
};
apiInstance.pageGet(url, country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **url** | **String**| Fully qualified page url. URL needs to be URL encoded | 
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**[Page]**](Page.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pagesGet"></a>
# **pagesGet**
> [Pages] pagesGet(opts)

Get historical stats for pages

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.HistoricalApi();
let opts = { 
  'fromDate': "fromDate_example", // String | Datas from YYYY-MM-DD (if not provided, last 30 days)
  'toDate': "toDate_example", // String | Datas to YYYY-MM-DD (if not provided, last 30 days)
  'country': "country_example", // String | ISO_3166 country code in 2 letters (if not provided  worldwide)
  'subcountry': "subcountry_example", // String | state code
  'presetFilter': 56, // Number | Apply preset filters => 0 no filter 1 no headlines 2 only headlines 3 to 6 deprecated 7 no articles 8 only articles 9 no shorts 10 only shorts 11 no showcase 12 only showcase 13 no video 14 only video 15 no webstory 16 only webstories
  'domainFilter': "domainFilter_example", // String | Filter answers to pages of a designated domain name
  'keywordFilter': "keywordFilter_example", // String | Filter answers to pages titles containing a particular keyword
  'entityFilter': "entityFilter_example", // String | Filter answers to pages with entities containing a particular keyword
  'urlFilter': "urlFilter_example", // String | Filter answers to pages URL including a specified string
  'categoryFilter': 56, // Number | Filter answers to a specific page category
  'languageFilter': "languageFilter_example", // String | Filter answers to pages in specific user language
  'lines': 50, // Number | Get X results (max in one request is 50000 a request with more than 50000 will be downgraded to 10000 please use offset paginated results if you need more)
  'offset': 0 // Number | Get paginated results from X offset
};
apiInstance.pagesGet(opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, last 30 days) | [optional] 
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, last 30 days) | [optional] 
 **country** | **String**| ISO_3166 country code in 2 letters (if not provided  worldwide) | [optional] 
 **subcountry** | **String**| state code | [optional] 
 **presetFilter** | **Number**| Apply preset filters &#x3D;&gt; 0 no filter 1 no headlines 2 only headlines 3 to 6 deprecated 7 no articles 8 only articles 9 no shorts 10 only shorts 11 no showcase 12 only showcase 13 no video 14 only video 15 no webstory 16 only webstories | [optional] 
 **domainFilter** | **String**| Filter answers to pages of a designated domain name | [optional] 
 **keywordFilter** | **String**| Filter answers to pages titles containing a particular keyword | [optional] 
 **entityFilter** | **String**| Filter answers to pages with entities containing a particular keyword | [optional] 
 **urlFilter** | **String**| Filter answers to pages URL including a specified string | [optional] 
 **categoryFilter** | **Number**| Filter answers to a specific page category | [optional] 
 **languageFilter** | **String**| Filter answers to pages in specific user language | [optional] 
 **lines** | **Number**| Get X results (max in one request is 50000 a request with more than 50000 will be downgraded to 10000 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Number**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**[Pages]**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

