# DiscoverSnoop.LiveApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**livecategoriesGet**](LiveApi.md#livecategoriesGet) | **GET** /livecategories | Get livedata stats for categories
[**livedomainsGet**](LiveApi.md#livedomainsGet) | **GET** /livedomains | Get livedata stats for domains
[**liveentitiesGet**](LiveApi.md#liveentitiesGet) | **GET** /liveentities | Get livedata stats for entities
[**livepagesGet**](LiveApi.md#livepagesGet) | **GET** /livepages | Get livedata stats for pages

<a name="livecategoriesGet"></a>
# **livecategoriesGet**
> [Categories] livecategoriesGet(country, opts)

Get livedata stats for categories

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.LiveApi();
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'hours': 56, // Number | Get results for last x hours
  'keywordFilter': "keywordFilter_example", // String | Filter answers to category names containing a particular keyword
  'languageFilter': "languageFilter_example", // String | Filter answers to pages in specific user language
  'lines': 50, // Number | Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more)
  'offset': 0 // Number | Get paginated results from X offset
};
apiInstance.livecategoriesGet(country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **hours** | **Number**| Get results for last x hours | [optional] 
 **keywordFilter** | **String**| Filter answers to category names containing a particular keyword | [optional] 
 **languageFilter** | **String**| Filter answers to pages in specific user language | [optional] 
 **lines** | **Number**| Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Number**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**[Categories]**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="livedomainsGet"></a>
# **livedomainsGet**
> [Domains] livedomainsGet(country, opts)

Get livedata stats for domains

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.LiveApi();
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'urlFilter': "urlFilter_example", // String | Filter answers to domains including a specified string
  'hours': 56, // Number | Get results for last x hours
  'lines': 50, // Number | Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more)
  'languageFilter': "languageFilter_example", // String | Filter answers to pages in specific user language
  'offset': 0 // Number | Get paginated results from X offset
};
apiInstance.livedomainsGet(country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **urlFilter** | **String**| Filter answers to domains including a specified string | [optional] 
 **hours** | **Number**| Get results for last x hours | [optional] 
 **lines** | **Number**| Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more) | [optional] [default to 50]
 **languageFilter** | **String**| Filter answers to pages in specific user language | [optional] 
 **offset** | **Number**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**[Domains]**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="liveentitiesGet"></a>
# **liveentitiesGet**
> [Entities] liveentitiesGet(country, opts)

Get livedata stats for entities

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.LiveApi();
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'hours': 56, // Number | Get results for last x hours
  'keywordFilter': "keywordFilter_example", // String | Filter answers to entity names containing a particular keyword
  'categoryFilter': 56, // Number | Filter answers to pages of a designated category id
  'languageFilter': "languageFilter_example", // String | Filter answers to pages in specific user language
  'domainFilter': "domainFilter_example", // String | Filter answers to pages of a designated domain name
  'lines': 50, // Number | Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more)
  'offset': 0 // Number | Get paginated results from X offset
};
apiInstance.liveentitiesGet(country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **hours** | **Number**| Get results for last x hours | [optional] 
 **keywordFilter** | **String**| Filter answers to entity names containing a particular keyword | [optional] 
 **categoryFilter** | **Number**| Filter answers to pages of a designated category id | [optional] 
 **languageFilter** | **String**| Filter answers to pages in specific user language | [optional] 
 **domainFilter** | **String**| Filter answers to pages of a designated domain name | [optional] 
 **lines** | **Number**| Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 10000 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Number**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**[Entities]**](Entities.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="livepagesGet"></a>
# **livepagesGet**
> [Pages] livepagesGet(country, opts)

Get livedata stats for pages

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.LiveApi();
let country = "country_example"; // String | ISO_3166 country code in 2 letters
let opts = { 
  'subcountry': "subcountry_example", // String | state code
  'hours': 56, // Number | Get results for last x hours
  'presetFilter': 56, // Number | Apply preset filters => 0 no filter, 1 no headlines, 2 only headlines, 3 to 6 deprecated, 7 no articles, 8 only articles, 9 no shorts, 10 only shorts, 11 no showcase, 12 only showcase, 13 no video, 14 only video, 15 no webstory, 16 only webstories
  'onlyNew': 0, // Number | Get only pages first seen in the reporting period if set on 1
  'domainFilter': "domainFilter_example", // String | Filter answers to pages of a designated domain name
  'keywordFilter': "keywordFilter_example", // String | Filter answers to pages titles containing a particular keyword
  'entityFilter': "entityFilter_example", // String | Filter answers to pages with entities containing a particular keyword
  'urlFilter': "urlFilter_example", // String | Filter answers to pages URL including a specified string
  'categoryFilter': 56, // Number | Filter answers to pages of a designated category id
  'languageFilter': "languageFilter_example", // String | Filter answers to pages in specific user language
  'lines': 50, // Number | Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 20 please use offset paginated results if you need more)
  'offset': 0 // Number | Get paginated results from X offset
};
apiInstance.livepagesGet(country, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **hours** | **Number**| Get results for last x hours | [optional] 
 **presetFilter** | **Number**| Apply preset filters &#x3D;&gt; 0 no filter, 1 no headlines, 2 only headlines, 3 to 6 deprecated, 7 no articles, 8 only articles, 9 no shorts, 10 only shorts, 11 no showcase, 12 only showcase, 13 no video, 14 only video, 15 no webstory, 16 only webstories | [optional] 
 **onlyNew** | **Number**| Get only pages first seen in the reporting period if set on 1 | [optional] [default to 0]
 **domainFilter** | **String**| Filter answers to pages of a designated domain name | [optional] 
 **keywordFilter** | **String**| Filter answers to pages titles containing a particular keyword | [optional] 
 **entityFilter** | **String**| Filter answers to pages with entities containing a particular keyword | [optional] 
 **urlFilter** | **String**| Filter answers to pages URL including a specified string | [optional] 
 **categoryFilter** | **Number**| Filter answers to pages of a designated category id | [optional] 
 **languageFilter** | **String**| Filter answers to pages in specific user language | [optional] 
 **lines** | **Number**| Get X results (max in one request is 10000 a request with more than 10000 will be downgraded to 20 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Number**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**[Pages]**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

