# DiscoverSnoop.UserApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**userCountriesChangeGet**](UserApi.md#userCountriesChangeGet) | **GET** /user_countries_change | Change user&#x27;s activated countries
[**userCustidChangeGet**](UserApi.md#userCustidChangeGet) | **GET** /user_custid_change | Change user customer id. This function is system reserved
[**userDeleteGet**](UserApi.md#userDeleteGet) | **GET** /user_delete | Permanently delete the user
[**userDetailsChangeGet**](UserApi.md#userDetailsChangeGet) | **GET** /user_details_change | Change user details
[**userLoginGet**](UserApi.md#userLoginGet) | **GET** /user_login | Login user with his credentials
[**userMessagesGet**](UserApi.md#userMessagesGet) | **GET** /user_messages | Get messages for user
[**userPasswordChangeGet**](UserApi.md#userPasswordChangeGet) | **GET** /user_password_change | Change user password
[**userPasswordResetGet**](UserApi.md#userPasswordResetGet) | **GET** /user_password_reset | Reset user password
[**userRefreshSubscriptionGet**](UserApi.md#userRefreshSubscriptionGet) | **GET** /user_refresh_subscription | Refresh user rights with his Customer ID. This function is system reserved
[**userRegisterGet**](UserApi.md#userRegisterGet) | **GET** /user_register | Login user with his credentials

<a name="userCountriesChangeGet"></a>
# **userCountriesChangeGet**
> [TransactionInfo] userCountriesChangeGet(countries, categories)

Change user&#x27;s activated countries

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
let countries = "countries_example"; // String | json encoded string representing countries to activate
let categories = "categories_example"; // String | json encoded string representing categories ID to activate

apiInstance.userCountriesChangeGet(countries, categories, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **countries** | **String**| json encoded string representing countries to activate | 
 **categories** | **String**| json encoded string representing categories ID to activate | 

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="userCustidChangeGet"></a>
# **userCustidChangeGet**
> [TransactionInfo] userCustidChangeGet(custid)

Change user customer id. This function is system reserved

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
let custid = "custid_example"; // String | new customer id for user

apiInstance.userCustidChangeGet(custid, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **custid** | **String**| new customer id for user | 

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="userDeleteGet"></a>
# **userDeleteGet**
> [TransactionInfo] userDeleteGet()

Permanently delete the user

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
apiInstance.userDeleteGet((error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="userDetailsChangeGet"></a>
# **userDetailsChangeGet**
> [TransactionInfo] userDetailsChangeGet(email, fname, lname, opts)

Change user details

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
let email = "email_example"; // String | new email address for user
let fname = "fname_example"; // String | new firstname for user
let lname = "lname_example"; // String | new lastname for user
let opts = { 
  'translation': "translation_example" // String | update the translation settings for user original (will show original titles) | english (will show titles translated in english)
};
apiInstance.userDetailsChangeGet(email, fname, lname, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **email** | **String**| new email address for user | 
 **fname** | **String**| new firstname for user | 
 **lname** | **String**| new lastname for user | 
 **translation** | **String**| update the translation settings for user original (will show original titles) | english (will show titles translated in english) | [optional] 

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="userLoginGet"></a>
# **userLoginGet**
> [UserInfo] userLoginGet(email, password, opts)

Login user with his credentials

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
let email = "email_example"; // String | email address for user
let password = "password_example"; // String | password for user
let opts = { 
  'pin': 56 // Number | pin code to validate account creation ; when using pin code, password must be set to \"loginwithpin\"
};
apiInstance.userLoginGet(email, password, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **email** | **String**| email address for user | 
 **password** | **String**| password for user | 
 **pin** | **Number**| pin code to validate account creation ; when using pin code, password must be set to \&quot;loginwithpin\&quot; | [optional] 

### Return type

[**[UserInfo]**](UserInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="userMessagesGet"></a>
# **userMessagesGet**
> [Message] userMessagesGet(opts)

Get messages for user

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
let opts = { 
  'message': 56 // Number | ID of the requested message. 0 to get the full message list
};
apiInstance.userMessagesGet(opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **message** | **Number**| ID of the requested message. 0 to get the full message list | [optional] 

### Return type

[**[Message]**](Message.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="userPasswordChangeGet"></a>
# **userPasswordChangeGet**
> [TransactionInfo] userPasswordChangeGet(email, password, newpassword)

Change user password

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
let email = "email_example"; // String | email address for user
let password = "password_example"; // String | current password for user
let newpassword = "newpassword_example"; // String | new password to set up for user

apiInstance.userPasswordChangeGet(email, password, newpassword, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **email** | **String**| email address for user | 
 **password** | **String**| current password for user | 
 **newpassword** | **String**| new password to set up for user | 

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="userPasswordResetGet"></a>
# **userPasswordResetGet**
> [TransactionInfo] userPasswordResetGet(email)

Reset user password

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
let email = "email_example"; // String | email address for user

apiInstance.userPasswordResetGet(email, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **email** | **String**| email address for user | 

### Return type

[**[TransactionInfo]**](TransactionInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="userRefreshSubscriptionGet"></a>
# **userRefreshSubscriptionGet**
> [UserInfo] userRefreshSubscriptionGet(custid)

Refresh user rights with his Customer ID. This function is system reserved

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
let custid = "custid_example"; // String | Customer ID for the user

apiInstance.userRefreshSubscriptionGet(custid, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **custid** | **String**| Customer ID for the user | 

### Return type

[**[UserInfo]**](UserInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="userRegisterGet"></a>
# **userRegisterGet**
> [UserInfo] userRegisterGet(email, password, fname, lname, opts)

Login user with his credentials

### Example
```javascript
import {DiscoverSnoop} from 'discover_snoop';
let defaultClient = DiscoverSnoop.ApiClient.instance;


let apiInstance = new DiscoverSnoop.UserApi();
let email = "email_example"; // String | email address for user
let password = "password_example"; // String | password for user
let fname = "fname_example"; // String | new firstname for user
let lname = "lname_example"; // String | new lastname for user
let opts = { 
  'referrer': "referrer_example" // String | referrer for this user. should be urlencoded
};
apiInstance.userRegisterGet(email, password, fname, lname, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **email** | **String**| email address for user | 
 **password** | **String**| password for user | 
 **fname** | **String**| new firstname for user | 
 **lname** | **String**| new lastname for user | 
 **referrer** | **String**| referrer for this user. should be urlencoded | [optional] 

### Return type

[**[UserInfo]**](UserInfo.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

